<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>IncDecVolumeCommandLineOption</name>
    <message>
        <location filename="../incdecvolumeoption.cpp" line="44"/>
        <source>Increase volume with step 5</source>
        <translation>增大声音(5个单位)</translation>
    </message>
    <message>
        <location filename="../incdecvolumeoption.cpp" line="45"/>
        <source>Decrease volume with step 5</source>
        <translation>降低声音(5个单位)</translation>
    </message>
</context>
</TS>
